(function (angular) {
    "use strict";
    // 引导页功能数据请求模块
    angular.module('global.service', [])
        .factory('GlobalFunFty', ['GlobalVariable', '$q', '$http', '$state', '$window', '$timeout', '$location', '$rootScope', '$stateParams',
            function (GlobalVariable, $q, $http, $state, $window, $timeout, $location, $rootScope, $stateParams) {
                return {
// -------------- WECHAT 相关 ---------------------
                    getWechatInfo: function () {
                        return;
                    },
                    wxShare: function (obj) {
                        return;
                    },
                    wxNoShare: function () {
                        return;
                    },
                    shareWechat: function (obj) {
                        var wx = api.require('wx');
                        wx.shareWebpage({
                            apiKey: '',
                            scene: obj.scene,
                            title: obj.title,
                            description: obj.description,
                            thumb: obj.thumb,
                            contentUrl: obj.contentUrl
                        }, function(ret, err) {
                            if (ret.status) {
                                alert('分享成功');
                            } else {
                                switch (err.code) {
                                    case -1:
                                        alert('未知错误，请稍后重试');
                                        break;
                                    case 0:
                                        alert('分享成功');
                                        break;
                                    case 1:
                                        alert('内部系统错误，错误码为：1');
                                        break;
                                    case 2:
                                        alert('您已取消分享');
                                        break;
                                    case 3:
                                        alert('分享发送失败，请稍后充实');
                                        break;
                                }
                            }
                        });
                    },
                    shareFriend: function (obj) {
                        obj.scene = 'timeline'
                        this.shareWechat(obj);
                    },
                    shareFriends: function (obj) {
                        obj.scene = 'session'
                        this.shareWechat(obj);
                    },
// -------------- FUNCTION ------------------------
                    goLogin: function () {
                        $state.go('login');
                    },                      // 去登陆页面
                    goError: function () {
                        $state.go('error');
                    },                      // 去登陆页面
                    errFun: function (msg) {
                        var deferred = $q.defer();
                        deferred.reject(msg)
                        return deferred.promise
                        // return Promise.reject(msg);
                    },
                    info: function (msg) {
                        if(GlobalVariable.DEVELOP_VAL){
                            $window.console.log(msg);
                        }
                    },
                    /**
                     * 检测是否登陆 如果登陆则执行 fn 函数
                     * @param isGoLogin 如果没有登陆是否跳转的 login 页面
                     * @param fn    执行的回掉   参数是一个对象
                     * @returns {*} 未登录返回 false 否则返回回掉函数的值
                     */
                    detLogin: function (isGoLogin, fn) {
                        var deferred = $q.defer()
                        if (this.getLocal('uuid') && this.getLocal('signature')) {
                            if (fn) {
                                return fn({
                                    uuid: this.getLocal('uuid'),
                                    signature: this.getLocal('signature')
                                });
                            }
                            deferred.resolve(true);// 已登陆
                        } else if (isGoLogin) {
                            $rootScope.currentPage = $state.current;
                            if($stateParams){
                                $rootScope.currentPage.params = this.paramsCopy({}, $stateParams);
                            }
                            this.goLogin();
                        }else if(fn){
                            return fn(null);
                        }
                        deferred.reject("您还没有登录。请登录后再操作");// 没有登陆
                        return deferred.promise;
                    },
                    getUserInfo: function () {
                        return this.detLogin(false, function (obj) {
                            return obj || null;
                        })
                    },
                    /**
                     * 把 obj2 复制到 obj1 上 不修改原对象 返回新的对象
                     * @param obj1
                     * @param obj2
                     * @returns {*}
                     */
                    paramsCopy: function (obj1, obj2) {
                        var obj = angular.copy(obj1)
                        if (!obj2) return obj1;
                        angular.forEach(obj2, function (val, key) {
                            obj[key] = obj2[key];
                        })
                        return obj
                    },
                    JrollRefresh: function (Jroll, time, scrollTo) {
                        time = time || 200
                        $timeout(function () {
                            Jroll.refresh();    // 先刷新下
                            if(scrollTo) {
                                Jroll.scrollTo(0,scrollTo,0)    // 然后滚动到滚动的位置
                                Jroll.refresh();    // 然后在刷新下 就可以触发 refresh 事件 就可以在滚动完成后 做些东西
                            }
                        }, time)
                    },
// ------------- GET、POST 请求 --------------------
                    /**
                     * ajax 请求封装 返回一个 promise 对象
                     */
                    dataParams: function (obj) {
                        var str = '', count = 0;
                        angular.forEach(obj, function (val, key) {
                            var first = count ? '&' : ''
                            str += first + key + '=' + val;
                            count++
                        })
                        return str;
                    },                  //  对象序列化的字符串表示
                    getPostInfos: function (obj) {
                        obj.data = obj.data || {};
                        var deferred = $q.defer();
                        // 如果 data 是对象的话 就把他序列化
                        obj.data = obj.data.toString() == '[object Object]' ? this.dataParams(obj.data) : obj.data;
                        $http({
                            method: 'POST',
                            url: obj.url,
                            headers: obj.headers || {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'},
                            data: obj.data,
                        }).then(function (data) {

                            if (data.data.success) {
                                deferred.resolve(data)
                            } else {
                                deferred.reject(data.data.message);
                            }

                        }, function (err) {
                            deferred.reject(err);
                        });
                        return deferred.promise;
                    },
                    getGetInfos: function (obj) {
                        obj.data = obj.data || {};
                        var deferred = $q.defer();
                        $http({
                            method: 'GET',
                            url: obj.url,
                            params: obj.data
                        }).then(function (data) {
                            if (data.data.success) {
                                deferred.resolve(data)
                            } else {
                                deferred.reject(data.data.message);
                            }

                        }, function (err) {
                            deferred.reject(err);
                        });
                        return deferred.promise;
                    },
                    upLoadImage: function (formData) {
                        return this.getPostInfos({
                            url: GlobalVariable.UPLOAD_IMAGE,
                            headers: {'Content-Type': undefined},
                            data: formData
                        })
                    },
// -------------- STORAGE 相关 ---------------------
                    /**
                     *
                     * localstorage  返回字符串或者 null
                     */
                    isStorageWorking: function () {
                        var testKey = 'test', storage = $window.localStorage;
                        try {
                            storage.setItem(testKey, '1');
                            storage.removeItem(testKey);
                            return true;
                        } catch (error) {
                            return false;
                        }
                    },
                    clearLocal: function (str1, str2, str3) {  //  字符串参数  内部使用 anguments 数组
                        for (var i = 0, len = arguments.length; i < len; i++) {
                            $window.localStorage.removeItem(arguments[i])
                        }
                        return null
                    },
                    clearSession: function (str1, str2, str3) {  //  字符串参数  内部使用 anguments 数组
                        for (var i = 0, len = arguments.length; i < len; i++) {
                            $window.sessionStorage.removeItem(arguments[i])
                        }
                        return null
                    },
                    getLocal: function (name) {
                        return $window.localStorage.getItem(name)
                    },
                    getSession: function (name) {
                        return $window.sessionStorage.getItem(name)
                    },
                    setLocal: function (name, val) {
                        return $window.localStorage.setItem(name, val)
                    },
                    setSession: function (name, val) {
                        return $window.sessionStorage.setItem(name, val)
                    },
// -------------- URL 相关 ------------------------
                    /**
                     * 获取 URL 参数
                     * @param name
                     * @returns {*} 没有则返回 null 有则返回 String
                     */
                    getQueryString: function (name) {   // 获取 Url 参数匹配
                        var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i"); //构造一个含有目标参数的正则表达式对￿
                        var r = $window.location.search.substr(1).match(reg);  //匹配目标参数
                        if (r != null) return decodeURIComponent(r[2]);
                        return null;                // 返回参数￿
                    },       // 获取页面参数

//------------------ MUDEL 相关 -------------------------------
                    msg: function (msg, time) {       // layer msg提示
                        time = time || 2;
                        $window.layer.open({
                            content: msg
                            , skin: 'msg'
                            , time: time           //    2秒后自动关闭
                        });
                    },                 // 仿 iphone 信息提示
                    showAddProvide: function (title, fn) {
                        //信息框
                        $window.layer.open({
                            content: '<span class="iconfont icon-caigou1"></span>' +
                            ' <p>'+ title +'订单已生成</p> ' +
                            '<p> 交易员会在30min内和您联系</p>' +
                            ' <p> <button>完成</button></p>',
                            className: 'add-provide',
                            shadeClose: false,
                            success: function (layero) {
                                angular.element(layero).find('button').on('click', function () {
                                    $window.layer.closeAll();
                                })
                                fn && fn();
                            }
                        });

                    },         // 商品详情订单生成提示窗口
                    showDelMessage: function (fn) {
                        //信息框
                        $window.layer.open({
                            content: '<div>' +
                            '<div> ' +
                            '<i class="iconfont icon-shanchu2"></i>'+
                            '<h3>确定删除消息</h3>' +
                            ' <h4>删除消息之后将无法恢复</h4> ' +
                            '<button>确认</button>' +
                            ' </div>',
                            className: 'del-message',
                            success: function (layero) {
                                angular.element(layero).find('i').on('click', function () {
                                    $window.layer.closeAll();
                                })
                                angular.element(layero).find('button').on('click', function () {
                                    fn && fn(function () {
                                        $window.layer.closeAll();
                                    });
                                })
                            }
                        });

                    },         // 消息列表删除提示
                    showDelImage: function (enent, index, fn) {
                        $window.layer.open({
                            content: '确认删除照片吗？'
                            , btn: ['取消', '确定']
                            , style: 'color:#333;'
                            , skin: 'footer'
                            , no: function () {
                                $window.layer.closeAll();

                                fn && fn(angular.element(enent.target), index)
                            }
                        });
                    },      // image 删除提示
                    showEnterpriseIn: function () {
                        $window.layer.open({
                            content: '个人认证过程中无法进行企业认证，请确定个人认证已成功或者失败'
                            , btn: ['去首页', '查看状态']
                            , shadeClose: false
                            , yes: function (index) {
                                $state.go('tab.home')
                                layer.close(index);
                            }
                            , no: function (index) {
                                $state.go('authentication.state', {
                                    currentChoose: 'personal',
                                    state: 'ing'
                                })
                                layer.close(index);
                            }
                        });
                    },      // 个人认证点击企业认证提示
                    showImageList: function (str) {
                        var _this = this;
                        $window.layer.open({
                            content: '<img src="'+str+'" class="show-image"> <i class="iconfont icon-shanchu2 show-image-close"></i>',
                            type: 1,
                            className:'show-image-box',
                            success: function (ele) {
                                angular.element(ele).find('i').on('click', function () {
                                    _this.closeAll();
                                })
                            },
                        });
                    },
                    showSearch: function () {
                        var where;
                        switch ($state.current.name){
                            case "supermarket":
                                where = 2;
                                break;
                            case "tab.purchase":
                                where = 1;
                                break;
                            default:
                                where = 0;
                                break;
                        }
                        var way = 0,
                            _this = this,
                            categoryApi = '/category/getMeatCategoryInfos',
                            history = function () {
                                $('#search-main .search-history').empty();
                                var seachHistory = JSON.parse(_this.getLocal('keyWord' + way)) || [], str = '';
                                if (seachHistory.length) {
                                    angular.forEach(seachHistory, function (val, key) {
                                        str += '<li>' + val + '</li>'
                                    })
                                } else {
                                    str = '<li>无</li>'
                                }
                                $('#search-main .search-history').append(str)
                            },
                            goNewPage = function (data) {
                                if (data === '无') {
                                    return;
                                }
                                var seachHistory = JSON.parse(_this.getLocal('keyWord' + way)) || [];
                                var index = seachHistory.indexOf(data);
                                var meatType = $('#search-header input[type="hidden"]').val();
                                if (index >= 0) {
                                    seachHistory.splice(index, 1)
                                }
                                seachHistory.unshift(data)
                                if (seachHistory.length > 5) {
                                    seachHistory.length = 5;
                                }
                                _this.setLocal('keyWord' + way, JSON.stringify(seachHistory))
                                if (way === 0) {
                                    $state.go('tab.supply', {
                                        keyWord: data,
                                        meatType: meatType
                                    })
                                } else if (way === 1) {
                                    $state.go('tab.purchase', {
                                        keyWord: data,
                                        meatType: meatType
                                    })
                                } else {
                                    $state.go('supermarket', {
                                        name: data,
                                    })
                                }
                                layer.closeAll();
                            };
                        var pageii = layer.open({
                            type: 1,
                            content: '<header id="search-header">' +
                            '<i class="back iconfont icon-jiantou-copy"></i>' +
                            '<div class="searchI">' +
                            '<form action="javascript:;" id="formFor">' +
                            '<input type="hidden" name="meatype" value="0">' +
                            '<input type="search" name="keyWord" placeholder="请输入搜索关键词">' +
                            '<div class="option iconfont icon-qiehuan"><span>牛肉</span></div>' +
                            '<i class="searchRe iconfont icon-llhomesearch"></i>' +
                            '</form>' +
                            '<ul class="searchResoult hide"></ul>' +
                            '</div>' +
                            '</header>' +
                            '<main id="search-main">' +
                            '<ul class="title">' +
                            '<li data-way="0" class=""><span class="iconfont icon-woyaogonghuo">供应</span></li>' +
                            '<li data-way="1" class=""><span class="iconfont icon-iconfontzhanshiwenzhang">采购</span></li>' +
                            '<li data-way="2" class=""><span class="iconfont icon-shangdian1">店铺</span></li>' +
                            '</ul>' +
                            '<h3 class="iconfont icon-sousuolishi">历史搜索 <span class="iconfont icon-shanchu1"></span></h3>' +
                            '<ul class="search-history"></ul>' +
                            '</main>',
                            anim: 'up',
                            style: 'position:fixed; left:0; top:0; background-color:#F5F5F5; width:100%; height:100%; border: none; -webkit-animation-duration: .5s; animation-duration: .5s;',
                            success: function (layero, index) {
                                var arr = ['牛肉', '羊肉']
                                // 默认渲染 历史记录
                                history()
                                // 搜索点击
                                $('#search-header .option').on('click', function () {
                                    var text = $(this).find('span').text();
                                    if (text === '牛肉') {
                                        $(this).find('span').text('羊肉')
                                        $('#search-header input[type="hidden"]').val('1')
                                    } else {
                                        $('#search-header input[type="hidden"]').val('0')
                                        $(this).find('span').text('牛肉')
                                    }
                                })
                                // 模糊搜索提示
                                $('#search-header input[type="search"]').on('input', function () {
                                    var val = $(this).val().trim(),
                                        $this = $(this);
                                    if (val) {
                                        _this.getGetInfos({
                                            url: GlobalVariable.SERVER_PATH + categoryApi,
                                            data: {keyWord: val}
                                        }).then(function (data) {
                                            var numData = data.data.data.slice(0, 10), htmlStr = '';
                                            angular.forEach(numData, function (val, key) {
                                                htmlStr += '<li>' + val.meatName + '</li>'
                                            })
                                            $this.parent('form').siblings('.searchResoult').removeClass('hide').html(htmlStr)
                                        }, function (err) {
                                            this.info(err);
                                        })
                                    } else {
                                        $this.parent('form').siblings('.searchResoult').addClass('hide')
                                    }
                                })

                                // 模糊搜索结果点击
                                $('#search-header .searchResoult').on('click', 'li', function () {
                                    var value = $(this).text().trim()
                                    if (!value) {
                                        return
                                    }
                                    goNewPage(value)
                                })
                                $('#formFor').on('submit', function () {
                                    var vla = (document.forms['formFor'][1].value).trim();
                                    if (vla) {
                                        goNewPage(vla)
                                    }
                                })
                                // 清除历史纪录
                                $('#search-main h3 span').on('click', function () {
                                    $window.localStorage.removeItem('keyWord' + way)
                                    $('#search-main .search-history').empty();
                                    $('#search-main .search-history').append('<li>无</li>')
                                })
                                // 搜索按钮点击
                                $('#search-header .searchRe').on('click', function () {
                                    var value = $('#search-header input[type="search"]').val().trim();
                                    if (!value) {
                                        return
                                    }
                                    goNewPage(value)
                                })
                                // 历史搜索点击
                                $('#search-main .search-history').on('click', 'li', function () {
                                    var value = $(this).text().trim()
                                    if (!value) {
                                        return
                                    }
                                    goNewPage(value)
                                })

                                // 切换teb lan
                                $('#search-main .title li').on('click', function () {
                                    var val = $(this).data('way')
                                    if (val != undefined) {
                                        $(this).addClass('search-active').siblings('li').removeClass('search-active')
                                        way = val;
                                        history();
                                        if (way === 1) {
                                            $('.option').show()
                                            $('#formFor input[type="search"]').attr('name', 'keyWord')
                                        } else if (way === 0) {
                                            $('.option').show()
                                            $('#formFor input[type="search"]').attr('name', 'keyWord')
                                        } else {
                                            $('.option').hide()
                                            $('#formFor input[type="search"]').attr('name', 'shopName')
                                        }

                                    }

                                })

                                // // 返回点击
                                $('#search-header .back').on('touchend', function () {
                                    $timeout(function () {
                                        $window.history.back()
                                    }, 50)
                                })

                                // 初始状态
                                $('#search-main .title li').eq(where).click();
                                $timeout(function () {
                                    $('#formFor input[type="search"]').focus();
                                }, 300);
                            }
                        });
                    },           // 公公搜索窗口
                    showShare: function (fn) {
                        $window.layer.open({
                            type: 1
                            ,content: '<div class="share-content">' +
                            '<div class="share-title"><img src="./img/wechat_share_line.png"><spen>分享至</spen><img src="./img/wechat_share_line.png" alt=""></div>'+
                            '<div class="share-body"><div></div><div></div></div>'+
                            '<div class="share-footer">取消</div>'+
                            '</div>'
                            ,anim: 'up'
                            ,style: 'position:fixed; bottom:0; left:0; width: 100%; height: 200px; padding:10px 0; border:none;'
                            ,success: function () {
                                fn && fn();
                            }
                        });
                    },           // 商品详情分享
                    showImgUpload: function (fn) {
                        $window.layer.open({
                            type: 2
                            , content: '图片上传中...'
                            , shadeClose: false,
                            success: function () {
                                // 上传图片
                                fn && fn();
                            }
                        });
                    },    // image 上传 loading 窗口
                    showgenderModel: function (fn) {
                        var _this = this;
                        $window.layer.open({
                            className: 'gender',
                            type: 1,
                            content: '<h4>性别选择</h4><ul><li>男</li><li>女</li></ul><button>取消</button>',
                            success: function (ele) {
                                $('.gender button').on('click', function () {
                                    _this.closeAll()
                                })
                                $('.gender li').on('click', function () {
                                    var text = $(this).text().trim();
                                    fn && fn(text)
                                    _this.closeAll()
                                })
                            }
                        });
                    },
                    closeAll: function () {
                        $window.layer.closeAll();
                    },                // 关闭layer 提示
                };
            }]);

}(window.angular));