(function (angular) {
    "use strict";
    // 引导页功能数据请求模块
    angular.module('authBegain.service', ['global.service'])
        .factory('AuthBegainFty', ['GlobalVariable', 'GlobalFunFty', '$timeout','$q',
            function (GlobalVariable, GlobalFunFty, $timeout, $q) {
                return {
                    getAllGoodsLocusApi: GlobalVariable.SERVER_PATH + '/goodsLocus/searchAllGoodsLocus',    // 获取所在地
                    addUserAuthenticateApi: GlobalVariable.SERVER_PATH + '/myhome/userident/authenticate',    // 个人认证
                    addEnterAuthenticateApi: GlobalVariable.SERVER_PATH + '/myhome/enterpriseident/authenticate',    // 个人认证
                    refreshJroll: function (Jroll) {
                        GlobalFunFty.JrollRefresh(Jroll);
                    },
                    replaceParams: function (obj, imageList, sta) {
                        // 个人认证
                        var nweobj = {
                            uuid: GlobalFunFty.getLocal('uuid'), //必填  用户uuid
                            signature: GlobalFunFty.getLocal('signature'),            //必填  访问签名
                            address: obj.address.address + '市' + obj.address.street,        //必填  企业地址
                            businessType: obj.businessType.niu ? obj.businessType.yang ? 3 : 1 : obj.businessType.yang ? 2 : '',//必填  业务种类   1:牛类别   2:羊类别   3:牛羊类别
                            identityName: obj.identityName,          //必填  名字
                            indetityNumber: obj.indetityNumber,        //必填  身份证号码
                            pictureFront: imageList.pictureFront,         //必填  身份证正面
                            pictureBack: imageList.pictureBack,          //必填  身份证反面
                            handheldPhoto: imageList.handheldPhoto,         //必填  手持身份证
                        };
                        if (sta === "personal") {return nweobj;}
                        // 企业认证
                        return GlobalFunFty.paramsCopy(nweobj, {
                            enterpriseName: obj.enterpriseName,        //必填  企业名字
                            address: obj.address.address + '市' + obj.address.street,        //必填  企业地址
                            businessType: obj.businessType.niu ? obj.businessType.yang ? 3 : 1 : obj.businessType.yang ? 2 : '',//必填  业务种类   1:牛类别   2:羊类别   3:牛羊类别
                            phone: obj.phone,         //必填  手机号
                            businessLicensePic: imageList.businessLicensePic,   //必填  营业执照
                        });
                    },
                    ValidationData: function (obj, imagelist, sta) {   // 验证数据
                        var msg = {
                            enterpriseName: "企业名称",
                            address: "地址的省市",
                            businessType: "业务种类",
                            phone: "联系电话",
                            identityName: "真实姓名",
                            indetityNumber: "身份证号码",
                            businessLicensePic: "营业执照",
                            pictureFront: "身份证正面",
                            pictureBack: "身份证反面",
                            handheldPhoto: "手持身份证",
                        },
                            changeObj = this.replaceParams(obj, imagelist, sta);

                        for (var key in changeObj){
                            if (!changeObj[key]) {
                                GlobalFunFty.msg(msg[key] + "不能为空");
                                return false;
                            }
                            if (key === 'address' && !(changeObj[key].split("市")[0])) {
                                GlobalFunFty.msg(msg[key] + "不能为空");
                                return false;
                            }
                            if (key === 'phone' && !(GlobalVariable.TEST_PHONE_REGXP.test(changeObj[key]))) {
                                GlobalFunFty.msg("手机号码格式不正确");
                                return false;
                            }
                            if (key === 'indetityNumber' && !(/(^\d{15}$)|(^\d{17}([0-9]|X|x)$)/.test(changeObj[key]))) {
                                GlobalFunFty.msg("身份证格式不正确");
                                return false;
                            }
                        }
                        return changeObj; // 验证通过就 return obj
                    },
                    uploadImage: function (imageList) {
                        var imglist = {},
                            deferred = $q.defer(),
                            count = 1,
                            len = Object.keys(imageList).length;
                        angular.forEach(imageList, function (val, key) {
                            if (val.imageList.formData instanceof Object) {
                                // 上传图片
                                GlobalFunFty.getPostInfos({
                                    url: GlobalVariable.UPLOAD_IMAGE,
                                    headers: {'Content-Type': undefined},
                                    data: val.imageList.formData
                                }).then(function (data) {
                                    imglist[key] = data.data.message;
                                    if (count === len) {
                                        deferred.resolve(imglist);
                                    }
                                    count++;
                                }, function (err) {
                                    deferred.reject(err);
                                });
                            } else {
                                if(val.imageList.base64.indexOf('http://img.zhaoniuw.com/') > -1) {
                                    imglist[key] = val.imageList.base64.split('http://img.zhaoniuw.com/')[1];
                                }else {
                                    imglist[key] = val.imageList.base64.split('/')[5];
                                }
                                if (count === len) {
                                    deferred.resolve(imglist);
                                }
                                count++;
                            }

                        });
                        return deferred.promise;
                    },
                    failParams: function (params, imagelist, data, oss) {
                        var DataObj = {
                            enterpriseName: data.enterpriseIdentity.enterpriseName,
                            businessType: {
                                niu: data.businessType === 3 ? true : data.businessType === 1 ? true : false,
                                yang: data.businessType === 3 ? true : data.businessType === 2 ? true : false
                            },
                            address: {
                                address: data.userIdentity.address.split("市")[0],
                                street: data.userIdentity.address.split("市")[1]
                            },
                            businessLicensePic: data.enterpriseIdentity.businessLicensePic && data.enterpriseIdentity.businessLicensePic.split('?')[0] + oss,
                            phone: data.userIdentity.phone,
                            identityName: data.userIdentity.identityName,
                            indetityNumber: data.userIdentity.indetityNumber,
                            pictureFront: data.userIdentity.pictureFront && data.userIdentity.pictureFront.split('?')[0] + oss,
                            pictureBack: data.userIdentity.pictureBack && data.userIdentity.pictureBack.split('?')[0] + oss,
                            handheldPhoto: data.userIdentity.handheldPhoto && data.userIdentity.handheldPhoto.split('?')[0] + oss,
                        };
                        var imgData = {    // 储存image
                            businessLicensePic: {
                                imageList: {
                                    base64: DataObj.businessLicensePic
                                }
                            },
                            pictureFront: {
                                imageList: {
                                    base64: DataObj.pictureFront
                                }
                            },
                            pictureBack: {
                                imageList: {
                                    base64: DataObj.pictureBack
                                }
                            },
                            handheldPhoto: {
                                imageList: {
                                    base64: DataObj.handheldPhoto
                                }
                            }
                        };
                        angular.forEach(params, function (val, key) {
                            params[key] = DataObj[key];
                        });
                        angular.forEach(imagelist, function (val, key) {
                            imagelist[key] = imgData[key];
                        });
                        return {
                            sublimeParams: params,
                            imageList: imagelist
                        };
                    },
                    wechat: function () {
                        GlobalFunFty.wxNoShare();
                    }
                };
            }]);

})(window.angular);