(function (angular) {
    "use strict";
    angular.module('collectList.controller', ['collect.service', 'global.service'])
        .controller('CollectListCtrl', ['$scope', 'GlobalVariable', 'CollectFty', 'GlobalFunFty',
            function ($scope, GlobalVariable, CollectFty, GlobalFunFty) {

                $scope.deletethis = false;                  // 删除
                $scope.notData = false;                     // 是否有数据
                $scope.pms_isMoreItemsAvailable = true;     // 正在加载
                $scope.text = "正在加载...";                 // 正在加载显示文案
                $scope.offset = 0;                          // 第几页
                $scope.datalist = [];                          // 数据
                $scope.selected = {                         // 取消收藏数据集合
                    id: [],
                    index: []
                };

                /**
                 * 首屏渲染或者下拉刷新渲染
                 * @param fn Function
                 */
                $scope.refreshGoodsList = function (fn) {
                    // 下拉刷新后 初始化所有数据
                    $scope.notData = false;                     // 是否有数据
                    $scope.datalist = [];
                    $scope.pms_isMoreItemsAvailable = true;     // 正在加载
                    $scope.text = "正在加载...";                 // 正在加载显示文案
                    $scope.offset = 0;                          // 第几页
                    $scope.selected = {                         // 取消收藏数据集合
                        id: [],
                        index: []
                    };

                    // 发送请求数据
                    CollectFty.getPageInfo({
                        pageSize: 10,
                        offset: $scope.offset,
                    })
                        .then(function (data) {
                            var PageData = data.data;
                            if (PageData.total) {
                                $scope.datalist = PageData.data;
                                if (PageData.data.length < 10) {
                                    $scope.pms_isMoreItemsAvailable = false;
                                    $scope.text = '已加载完全部数据';
                                } else {
                                    $scope.pms_isMoreItemsAvailable = true;
                                    $scope.text = '正在加载...';
                                }
                            } else {
                                $scope.pms_isMoreItemsAvailable = false;
                                $scope.text = '已加载完全部数据';
                                $scope.notData = true;
                            }
                        }, function (err) {
                            GlobalFunFty.info(err);
                        })
                        .finally(function () {
                            if(fn){
                                fn();
                            }
                            GlobalFunFty.JrollRefresh($scope.jroll);
                        });
                };

                /**
                 * 加载更多 # 翻页
                 */
                $scope.loadMoreGoodsList = function () {

                    $scope.offset += 1;
                    CollectFty.getPageInfo({
                        offset: $scope.offset,
                        pageSize: 10,
                    })
                        .then(function (data) {
                            var pageData = data.data;
                            if (pageData.data.length < 10) {
                                $scope.pms_isMoreItemsAvailable = false;
                                $scope.text = '已加载完全部数据';
                            } else {
                                $scope.pms_isMoreItemsAvailable = true;
                                $scope.text = '正在加载...';
                            }
                            $scope.datalist = $scope.datalist.concat(pageData.data);
                        }, function (err) {
                            GlobalFunFty.info(err);
                        })
                        .finally(function () {
                            GlobalFunFty.JrollRefresh($scope.jroll);
                        });
                };

                // 默认的首屏渲染
                $scope.refreshGoodsList();

                // ng-repeat 循环完成触发事件 jroll refresh 事件 由于 repeat 延迟问题 造成当前高度获取错误问题 使用延迟定时器解决
                $scope.repeatFinish = function () {
                    GlobalFunFty.JrollRefresh($scope.jroll);
                };

                // 这是 jroll 初始化完成事件  接受 scroll-content 事件
                $scope.$on('scroll-finish', function ($event, data) {
                    $event.stopPropagation();
                    $scope.jroll = data;

                    // 判断是否到底部  进行下一页加载
                    $scope.jroll.on("scrollEnd", function () {
                        if (this.y === this.maxScrollY && $scope.pms_isMoreItemsAvailable) {
                            $scope.loadMoreGoodsList();
                        }
                    });

                    // 下拉刷新插件
                    $scope.jroll.pulldown({
                        iconArro: 'img/pull.png',
                        iconLoadin: 'img/pull_loading.gif',
                        iconFinis: 'img/pull_finish.png',
                        spinning: false,    // 使用的是自带的图片 禁止 icon 旋转；
                        refresh: function (complete) {
                            $scope.refreshGoodsList(function () {
                                complete();
                            });
                        }

                    });
                });

                // 接受来自父亲的 删除按钮点击事件
                $scope.$on('del-click', function () {
                    // 每次点击重置 保存数组
                    $scope.selected = {
                        id: [],
                        index: []
                    };
                    $scope.deletethis = !$scope.deletethis;
                });

                // 多选 选择取消收藏的商品
                $scope.delSelect = function (id, index) {
                    $scope.selected.id.push(id);
                    $scope.selected.index.push(index);
                };

                // 取消收藏点击触发事件
                $scope.dele = function () {
                    if (!$scope.selected.id.length) {
                        GlobalFunFty.msg('您还没有选择。');
                        return;
                    }
                    CollectFty.delPageInfo({
                        'ids[]': $scope.selected.id,
                    })
                        .then(function (data) {
                            GlobalFunFty.msg("删除成功");
                            $scope.refreshGoodsList();
                            // 重新请求数据后 滚动到顶部
                            $scope.jroll.scrollTo(0,0,0);
                            if(!$scope.notData){
                                // 发出请求 更改页面布局
                                $scope.deletethis = !$scope.deletethis;
                                $scope.$emit('close', $scope.deletethis)
                            }
                        }, function (err) {
                            GlobalFunFty.msg(err);
                            GlobalFunFty.info(err);
                        });
                };
            }]);
})(window.angular);

