(function (angular) {
    "use strict";
    angular.module('login.controller', ['login.service', 'global.service'])
        .controller('LoginCtrl', ['$scope', '$state', '$window', 'GlobalVariable', 'LoginFty', 'GlobalFunFty',
            function ($scope, $state, $window, GlobalVariable, LoginFty, GlobalFunFty) {

                GlobalFunFty.wxShare();

                // 只要进这个页面 都清除登陆记录
                // LoginFty.clearAllLocal();

                // 登录数据
                $scope.formData = {
                    user: '',
                    passworld: '',
                    remember: true
                };
                // 初始化值
                $scope.signin = function () {
                    // 登录判断
                    if (!$scope.formData.user.trim() || !$scope.formData.passworld.trim()) {
                        GlobalFunFty.msg('账号或密码不能为空');
                        return;
                    }
                    if ($scope.formData.passworld.trim().length < 6 || $scope.formData.passworld.trim().length > 16) {
                        GlobalFunFty.msg('密码长度不对，应该在6 - 16 位之间');
                        return;
                    }
                    LoginFty.submit({
                        account: $scope.formData.user,
                        password: $scope.formData.passworld,
                        rememberMe: $scope.formData.remember
                    }, function () {
                        $scope.formData.passworld = '';
                    });

                };

                // --------------------------注册-----------------------------------------

                // 注册数据
                $scope.sign = {
                    username: '',
                    phone: '',
                    phoneVerifCode: '',
                    password: '',
                    confirmPwd: '',
                    checked: true,
                    agrrement: 'on'
                };
                // 检测数据
                $scope.signPass = {
                    username: false,    // 用户名
                    phone: false,   // 手机好
                    password: false,    // 密码
                    confirmPwd: false,  // 再次密码
                    cerifCode: false,   // 默认没有点击发送验证码
                };
                $scope.codeMsg = "发送验证码";
                // 检测用户名
                $scope.testUserName = function (name) {
                    if (!name) {
                        $scope.usernameErr = "用户名不为空";
                        $scope.signPass.username = false;
                        return;
                    }
                    LoginFty.testUserName(name)
                        .then(function (data) {
                            $scope.usernameErr = '';
                            $scope.signPass.username = true;
                        }, function (err) {
                            GlobalFunFty.info(err);
                            $scope.usernameErr = err;
                            $scope.signPass.username = false;
                        }).finally(function () {
                        // tod something
                    });
                };
                // 检测手机号
                $scope.testPhone = function (phone) {
                    if (!phone || !(GlobalVariable.TEST_PHONE_REGXP.test(phone))) {
                        $scope.phoneErr = "手机号不合法";
                        $scope.signPass.phone = false;
                        return;
                    }
                    LoginFty.testPhone(phone)
                        .then(function (data) {
                            $scope.phoneErr = "";
                            $scope.signPass.phone = true;
                        }, function (err) {
                            $scope.phoneErr = err;
                            $scope.signPass.phone = false;
                        });
                };
                // 检测密码
                $scope.testPassword = function (password) {
                    password = password || '';
                    if (!password || password.trim().length < 6 || password.trim().length >= 16) {
                        $scope.passwordErr = "密码长度不合法";
                        $scope.signPass.password = false;
                    } else {
                        $scope.passwordErr = "";
                        $scope.signPass.password = true;
                    }
                };
                // 检测密码
                $scope.testconfirmPwd = function (pwd, confirmPwd) {
                    if (pwd !== confirmPwd) {
                        $scope.passwordErr = "两次输入的密码不一致";
                        $scope.signPass.confirmPwd = false;
                    } else {
                        $scope.passwordErr = "";
                        $scope.signPass.confirmPwd = true;
                    }
                };
                // 发送验证码
                $scope.sendCode = function (phone) {
                    if ($scope.signPass.phone) {
                        if ($scope.codeMsg === "发送验证码") {
                            LoginFty.sendCode(phone)
                                .then(function (data) {
                                    $scope.signPass.cerifCode = true;
                                    var count = 120;
                                    $scope.time = $window.setInterval(function () {
                                        $scope.codeMsg = count + 's';
                                        count--;
                                        $scope.$apply();
                                        if (count === 0) {
                                            $window.clearInterval($scope.time);
                                            $scope.codeMsg = "发送验证码";
                                            $scope.$apply();
                                        }
                                    }, 1000);
                                }, function (err) {
                                    GlobalFunFty.info(err);
                                    GlobalFunFty.msg(err);
                                }).finally(function () {
                                // ToD something
                            });
                        } else {
                            return;
                        }

                    } else {
                        $scope.phoneErr = "请填写注册手机号";
                        GlobalFunFty.msg($scope.phoneErr);
                    }
                };
                $scope.signSubmit = function () {
                    for (var key in $scope.signPass) {
                        if ($scope.signPass.hasOwnProperty(key) && !$scope.signPass[key]) {
                            switch (key) {
                                case "username":
                                    GlobalFunFty.msg($scope.usernameErr);
                                    return false;
                                case "phone":
                                    GlobalFunFty.msg($scope.phoneErr);
                                    return false;
                                case "password":
                                    GlobalFunFty.msg($scope.passwordErr);
                                    return false;
                                case "confirmPwd":
                                    GlobalFunFty.msg($scope.passwordErr);
                                    return false;
                                case "cerifCode":
                                    GlobalFunFty.msg("请先发送验证码");
                                    return false;
                                default:
                                    break;
                            }
                        }
                    }
                    LoginFty.addUserInfo($scope.sign)
                        .then(function (data) {
                            GlobalFunFty.msg("注册成功，欢迎您成为找牛网的一员");
                            LoginFty.submit({
                                account: $scope.sign.username,
                                password: $scope.sign.password,
                                rememberMe: true
                            });
                        }, function (err) {
                            GlobalFunFty.msg(err);
                            GlobalFunFty.info(err);
                        });
                };
                //    ------------------------------找回密码功能-------------------------------------------
                $scope.findPass = {
                    phone: '',
                    password: '',
                    confirmPwd: '',
                    phoneVerifCode: '',
                };
                $scope.phoneInfo = "";
                $scope.testFindPassPhone = function (phone) {
                    if (!phone || !(GlobalVariable.TEST_PHONE_REGXP.test(phone))) {
                        $scope.phoneInfo = "手机号不合法";
                        $scope.signPass.phone = false;
                        return;
                    } else {
                        $scope.phoneInfo = "";
                        $scope.signPass.phone = true;
                    }
                };
                $scope.findPassWprd = function () {
                    $scope.signPass.username = true;
                    for (var key in $scope.signPass) {
                        if ($scope.signPass.hasOwnProperty(key) && !$scope.signPass[key]) {
                            switch (key) {
                                case "phone":
                                    GlobalFunFty.msg($scope.phoneErr);
                                    return false;
                                case "password":
                                    GlobalFunFty.msg($scope.passwordErr);
                                    return false;
                                case "confirmPwd":
                                    GlobalFunFty.msg($scope.passwordErr);
                                    return false;
                                case "cerifCode":
                                    GlobalFunFty.msg("请先发送验证码");
                                    return false;
                                default:
                                    break;
                            }
                        }
                    }
                    LoginFty.findPassWprd($scope.findPass)
                        .then(function (data) {
                            GlobalFunFty.msg("修改成功");
                            $state.go('login');
                            GlobalFunFty.info(data);
                        }, function (err) {
                            GlobalFunFty.msg(err);
                            GlobalFunFty.info(err);
                        });
                };
            }]);

})(window.angular);