(function (angular) {
    "use strict";
    angular.module('myShop.controller', ['myShop.service','global.service'])
        .controller('MyShopCtrl', ['$scope', 'GlobalFunFty', 'MyShopFty', '$state', '$stateParams',
            function ($scope, GlobalFunFty, MyShopFty, $state, $stateParams) {

                GlobalFunFty.wxNoShare();
                $scope.shopInfo = {
                    companyProfile: '',
                    shopName: '',
                    shopLogo: '',
                    uuid: '',
                    signature: ''
                };
                $scope.shop = false;    // 是否有店铺
                $scope.noshop = false;  // 是否没有店铺
                $scope.editor = false;  // 是否编辑了页面
                GlobalFunFty.detLogin(true, function (obj) {
                    obj.fromWhere = 2;
                    $scope.shopInfo.uuid = obj.uuid;
                    $scope.shopInfo.signature = obj.signature;
                    return MyShopFty.getShopInfo(obj);
                })
                    .then(function (data) {
                    if(data.data.data){
                        $scope.shopInfo.shopLogo = data.data.data.shopLogo;
                        $scope.shopInfo.companyProfile = data.data.data.enterpriseIdentity.companyProfile || '';
                        $scope.shopInfo.shopName = data.data.data.shopName || '';
                        $scope.shop = true;
                    }else {
                        $scope.noshop = true;
                    }
                }, function (err) {
                    $scope.noshop = true;
                    GlobalFunFty.info(err);
                }).finally(function () {
                    // 检测是否更改信息
                    $scope.$watch('shopInfo', function (newval, oldval) {
                        if(oldval === newval){return;}
                        $scope.editor = true;
                    }, true);
                    // 如果是从上传logo 页面过来的话就会有 imgsrc 就直接赋值
                    if($stateParams.imgsrc){
                        $scope.shopInfo.shopLogo = $stateParams.imgsrc;
                        $scope.editor = true;
                    }

                });

                $scope.saveData = function () {
                    if(!$scope.editor) {
                        $state.go('tab.account');
                        return;
                    }
                    var sendData = angular.copy($scope.shopInfo);
                    sendData.shopLogo = $stateParams.shopLogo || '';
                    MyShopFty.addShopInfo(sendData)
                        .then(function (data) {
                            GlobalFunFty.msg(data.data.message);
                        }, function (err) {
                            GlobalFunFty.msg(err);
                            GlobalFunFty.info(err);
                        }).finally(function () {
                        $state.go('tab.account');
                    });
                };

                // 上传图片
                $scope.imgInfo = {
                    changeInput: false,
                    imageList: {},
                    background: 'url("'+ 'img/attestation/upimg.png'+'") no-repeat center center',
                    backgroundSize: '56px 56px'
                };
                $scope.$on('to-imagelist', function (event, data) {
                    event.stopPropagation();
                    $scope.imgInfo = {
                        changeInput: data.changeInput,
                        imageList: data.imageList,
                        background: 'url("'+ data.imageList.base64 +'") no-repeat center center',
                        backgroundSize: 'cover',
                        shopLogo: ''
                    };
                    $scope.$apply();
                });
                $scope.uploadImg = function () {
                    if(!$scope.imgInfo.changeInput){
                        $state.go('myShop');
                        return;
                    }
                    GlobalFunFty.showImgUpload(function () {// 打开图片上传 loading 窗口
                        MyShopFty.uploadImage($scope.imgInfo.imageList.formData)
                            .then(function (data) {
                                $scope.imgInfo.shopLogo = data.data.message;
                            }, function (err) {
                                GlobalFunFty.info(err);
                            })
                            .finally(function (data, err) {
                                GlobalFunFty.closeAll();
                                $state.go('myShop',{
                                    shopLogo: $scope.imgInfo.shopLogo,
                                    imgsrc: $scope.imgInfo.imageList.base64
                                });
                            });
                    });
                };
            }]);

}(window.angular));