(function (angular, $) {
    "use strict";
    angular.module('personalStore.controller', ['personalStore.service', 'global.service'])
        .controller('PersonalStoreCtrl', ['$scope', 'GlobalFunFty', 'PersonalStoreFty', '$window', 'GlobalVariable',
            function ($scope, GlobalFunFty, PersonalStoreFty, $window, GlobalVariable) {
            $scope.getDataParams = {
                amountReverse: '',
                priceReverse: '',
            };// 请求参数

            $scope.offset = 0;

            $scope.allData = null;

            $scope.isMoreData = true;

            $scope.text = "正在加载...";

            $scope.hide = false;// 是否显示正在加载


            $scope.repeatFinish = function () {
                GlobalFunFty.JrollRefresh($scope.jroll);
            };// 刷新 reoeat 完成出发事件


            PersonalStoreFty.getShopInfo()
                .then(function (data) {
                    if(!data.data.data){
                        GlobalFunFty.goError();
                    }
                    PersonalStoreFty.wechat({
                        title: data.data.data.shopName,
                        imgUrl: data.data.data.shopLogo,
                        desc: data.data.data.enterpriseIdentity.companyProfile.slice(0, 39)
                    });
                    $scope.pageInfo = data.data.data;

                }, function (err) {
                    GlobalFunFty.info(err);
                });// 页面shop 信息填充


            $scope.getGoods = function (obj, fn) {

                if (!$scope.isMoreData) {return;}  //如果等于 false 说明已经没有数据了 不需要请求了

                $scope.offset = obj.offset || 0;

                if ($scope.offset === 0) {

                    $scope.allData = [];
                    if (!$scope.hide) {   // 如果为 true 则说明正在执行下拉动作 无需 scrollTo 到顶部

                        $scope.$watch('jroll', function () {// 检测 如果有 jroll 属性 则滚动到

                            $scope.jroll.scrollTo(0, 0, 0);
                        });
                    }

                }


                PersonalStoreFty.getGoods(obj)

                    .then(function (data) {

                        if (data.data.total < ($scope.offset + 1) * 10) {

                            $scope.isMoreData = false;

                            $scope.text = "已经加载完全部数据";
                        }
                        if(fn){
                            fn(data.data);
                        }

                    }, function (err) {
                        GlobalFunFty.info(err);
                    })

                    .finally(function () {
                        GlobalFunFty.JrollRefresh($scope.jroll);
                    });

            };// goods 请求函数

            $scope.$watch('getDataParams', function (nwe, old) {

                if(old === nwe) {return;}
                $scope.isMoreData = true;// 重置数据
                $scope.text = "正在加载...";
                if($scope.getDataParams.priceReverse === '' && $scope.getDataParams.amountReverse === ''){
                    $scope.changeColor = '';
                }else {
                    angular.forEach(nwe, function (val, key) {
                        if(nwe[key] !== old[key]){
                            $scope.changeColor = key;
                        }
                    });
                }
                $scope.getGoods($scope.getDataParams, function (data) {

                    $scope.allData = data.data;
                });// 页面 good 信息填充
            }, true);// tab 点击

            $scope.getGoods($scope.getDataParams, function (data) {

                $scope.allData = data.data;
            });// 页面 good 信息填充


            $scope.$on('scroll-finish', function ($event, data) {

                $event.stopPropagation();

                $scope.jroll = data;

                $scope.jroll.on("scrollEnd", function () {

                    if (this.y === this.maxScrollY && $scope.isMoreData) {

                        $scope.getGoods(GlobalFunFty.paramsCopy($scope.getDataParams, {

                            offset: ++$scope.offset

                        }), function (data) {
                            $scope.allData = $scope.allData.concat(data.data);
                        });
                    }

                });// 加载更多

                $scope.jroll.pulldown({
                    iconArro: 'img/pull.png',
                    iconLoadin: 'img/pull_loading.gif',
                    iconFinis: 'img/pull_finish.png',
                    spinning: false,    // 使用的是自带的图片 禁止 icon 旋转；
                    refresh: function (complete) {
                        $scope.hide = true;     // 重置数据
                        $scope.isMoreData = true;
                        $scope.text = "正在加载...";

                        $scope.getGoods(GlobalFunFty.paramsCopy($scope.getDataParams, {

                            offset: 0

                        }), function (data) {
                            complete();

                            $scope.allData = data.data;

                            $scope.hide = false;
                        });
                    }

                });// 下拉刷新


                $scope.jroll.on("refresh", function () {

                    var imgListS = $('.imgList', '#supermarket-content');

                    imgListS.each(function (v, e) {

                        e.JRollViewer = new $window.JRollViewer(e);
                    });
                }); // 图片查看集

            });// 初始化 jroll

            $scope.showShare = function () {

                GlobalFunFty.showShare();
            };// 点击分享

            $scope.clickCollect = function () {

                if($scope.pageInfo.isCollection){// 取消收藏
                    PersonalStoreFty.delCollect()
                        .then(function (data) {
                            $scope.pageInfo.isCollection = false;
                            GlobalFunFty.msg(data.data.message);
                        }, function (err) {
                            GlobalFunFty.msg(err);
                            GlobalFunFty.info(err);
                        });
                    return;
                }
                PersonalStoreFty.addCollect()
                    .then(function (data) {
                        $scope.pageInfo.isCollection = true;
                        GlobalFunFty.msg(data.data.message);
                    }, function (err) {
                        if(err =="店铺的id不能和自己的用户相同"){
                            GlobalFunFty.msg("自己不能收藏自己的店铺");
                            return;
                        }else {
                            GlobalFunFty.msg("收藏失败");
                        }
                        GlobalFunFty.info(err);
                    });

            };// 点击收藏


            // 图片 OSS
            $scope.oss = {
                icon: GlobalVariable.IMG_OSS_RULE().personalStore.shop_icon,
                goods: GlobalVariable.IMG_OSS_RULE().personalStore.goods,
            }
        }]);
}(window.angular, window.$));